@@ -9,12 +9,13 @@ class SectionLessConfigParser(RawConfigParser):  # pylint: disable=too-many-ance
     """
     Class reads ini file without sections.
     """
+
     def read(self, filenames, encoding=None):
         with open(filenames) as fdesc:
-            file_content = '[dummy_section]\n' + fdesc.read()
+            file_content = "[dummy_section]\n" + fdesc.read()
 
         self.read_string(file_content)
 
     def get(self, *args, **kwargs):  # pylint: disable=arguments-differ
-        super_args = ('dummy_section', ) + args
+        super_args = ("dummy_section",) + args
         return super().get(*super_args, **kwargs).strip("\"'")
